From: Namhyung Kim <namhyung....@lge.com>

Add config option for launching GTK browser for the specified command
by default.  Currently only 'report' command is supported.

Adding following line to the perfconfig file will have a same effect
of specifying --gtk option on command line (unless other related
options are not given).

$ cat ~/.perfconfig
[gtk]
report = true

Cc: Pekka Enberg <penb...@kernel.org>
Signed-off-by: Namhyung Kim <namhy...@kernel.org>
---
 tools/perf/perf.c | 15 ++++++++++-----
 1 file changed, 10 insertions(+), 5 deletions(-)

diff --git a/tools/perf/perf.c b/tools/perf/perf.c
index a0ae2902f9c9..0f661fbce6a8 100644
--- a/tools/perf/perf.c
+++ b/tools/perf/perf.c
@@ -85,21 +85,26 @@ int check_pager_config(const char *cmd)
        return c.val;
 }
 
-static int tui_command_config(const char *var, const char *value, void *data)
+static int browser_command_config(const char *var, const char *value, void 
*data)
 {
        struct pager_config *c = data;
        if (!prefixcmp(var, "tui.") && !strcmp(var + 4, c->cmd))
                c->val = perf_config_bool(var, value);
+       if (!prefixcmp(var, "gtk.") && !strcmp(var + 4, c->cmd))
+               c->val = perf_config_bool(var, value) ? 2 : 0;
        return 0;
 }
 
-/* returns 0 for "no tui", 1 for "use tui", and -1 for "not specified" */
-static int check_tui_config(const char *cmd)
+/*
+ * returns 0 for "no tui", 1 for "use tui", 2 for "use gtk",
+ * and -1 for "not specified"
+ */
+static int check_browser_config(const char *cmd)
 {
        struct pager_config c;
        c.cmd = cmd;
        c.val = -1;
-       perf_config(tui_command_config, &c);
+       perf_config(browser_command_config, &c);
        return c.val;
 }
 
@@ -302,7 +307,7 @@ static int run_builtin(struct cmd_struct *p, int argc, 
const char **argv)
                prefix = NULL; /* setup_perf_directory(); */
 
        if (use_browser == -1)
-               use_browser = check_tui_config(p->cmd);
+               use_browser = check_browser_config(p->cmd);
 
        if (use_pager == -1 && p->option & RUN_SETUP)
                use_pager = check_pager_config(p->cmd);
-- 
1.7.11.7

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to